# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-CPAN-Meta-Requirements
Summary:	A set of version requirements for a CPAN dist
Version:	2.125
Release:	1.%{__distinit}%{__distvers}
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/CPAN-Meta-Requirements/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DA/DAGOLDEN/CPAN-Meta-Requirements-%{version}.tar.gz 
Patch1:		CPAN-Meta-Requirements-2.123-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
BuildArch:	noarch
# Build
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(version) >= 0.77
# Test
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Test::More)
# Extra Tests (not run when bootstrapping due to circular build dependencies)
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(English)
BuildRequires:	perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
BuildRequires:	perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Pod::Wordlist::hanekomu)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling) >= 0.12, aspell-en
BuildRequires:	perl(Test::Version) >= 0.04
%endif

# Had a six-digit version in a previous life
%global six_digit_version %(echo %{version} | perl -p -e 's/(.*)/sprintf("%.6f", $1)/e')

# Provide the six-digit version of the module
%if "%{version}" != "%{six_digit_version}"
Provides:	perl(CPAN::Meta::Requirements) = %{six_digit_version}
%global __provides_exclude ^perl\\(CPAN::Meta::Requirements\\)
%endif

%description
A CPAN::Meta::Requirements object models a set of version constraints like
those specified in the META.yml or META.json files in CPAN distributions. It
can be built up by adding more and more constraints, and it will reduce them
to the simplest representation.

Logically impossible constraints will be identified immediately by thrown
exceptions.

%prep
%setup -q -n CPAN-Meta-Requirements-%{version}

# Patch test suite to work with old Test::More version if necessary
%if %{old_test_more}
%patch1 -p1
%endif

# Don't provide less than six-digit version of the module (prior to rpm 4.9)
%if "%{version}" != "%{six_digit_version}"
%global perl_prov /bin/sh -c "%{__perl_provides} | sed -e '/^perl(CPAN::Meta::Requirements)/d'"
%define __perl_provides %{perl_prov}
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}

%check
make test AUTHOR_TESTING=1
%if 0%{!?perl_bootstrap:1}
LANG=en_US make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"
%endif

%files
%defattr(-,root,root,-)
%doc Changes CONTRIBUTING LICENSE README
%{perl_vendorlib}/CPAN/
%{_mandir}/man3/CPAN::Meta::Requirements.3pm*

%changelog
* Mon Sep 23 2013 Paul Howarth <paul@city-fan.org> - 2.125-1
- Update to 2.125
  - Updated Makefile.PL logic to support PERL_NO_HIGHLANDER

* Mon Sep 23 2013 Paul Howarth <paul@city-fan.org> - 2.124-1
- Update to 2.124
  - Better fix than 2.123: on old perls, rather than install into 'core', we
    continue to install into the proper 'site' library, but force UNINST=1 when
    necessary to remove stale copies from ExtUtils::MakeMaker

* Sat Aug 31 2013 Paul Howarth <paul@city-fan.org> - 2.123-1
- Update to 2.123
  - On Perls prior to v5.12, CPAN::Meta::Requirements will be installed into
    the 'core' library path to avoid an older version bundled with
    ExtUtils::MakeMaker and installed there taking precedence
- Drop now-redundant buildreq perl(Test::Requires) and associated patch
- Add new buildreqs for tests: perl(File::Spec::Functions), perl(IO::Handle),
  perl(IPC::Open3), perl(List::Util) and perl(Test::MinimumVersion)
- Run test suite with AUTHOR_TESTING=1 for additional coverage

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 2.122-290
- Perl 5.18 rebuild

* Thu Aug 23 2012 Paul Howarth <paul@city-fan.org> - 2.122-5
- Don't run extra tests when bootstrapping

* Sat Jul 14 2012 Paul Howarth <paul@city-fan.org> - 2.122-4
- Drop BR: perl(File::Find), not dual-lived
- BR: perl(English)
- BR: perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords)
- Specify version requirements for perl(Test::Pod), perl(Test::Pod::Coverage)
  and perl(Test::Spelling)

* Thu May  3 2012 Paul Howarth <paul@city-fan.org> - 2.122-1
- Update to 2.122
  - Fix typo in documentation: the exclusion symbol is "!=" rather than just
    "!"; the implementation was correct, just the docs were wrong
   (CPAN RT#76948)
- Update patches as necessary

* Tue Apr  3 2012 Paul Howarth <paul@city-fan.org> - 2.121-3
- Provide six-digit version number of module

* Sun Apr  1 2012 Paul Howarth <paul@city-fan.org> - 2.121-1
- Initial RPM version, split from perl-CPAN-Meta
